@echo off
REM gnuplot2ps, vers. 1.00, 2010-Apr-22, Author Stefan Pofahl (stefan@pofahl.de)
REM gnuplot2ps, vers. 1.10, 2010-Mai-19, pdflatex option added
REM 
REM Purpose:
REM compile a set of gnuplot "epslatex standalone" output files to grafic files
REM v1.00 supports: *.eps, *.ps, *.pdf output 
REM This batch file is tested under MikTeX 2.8 (OS: MS-WIN32, e.g. MS-WIN-XP)
REM together with Ghostscript
REM
REM usage:
REM 1.) put this file in the binary directory of your MikTeX installation 
REM 2.) edit variable "miktexpath" to be confirm with your current MiKTeX-installation 
REM 3.) add a system call at the end of your gnuplot script
REM     e.g.:
REM     ## --- begin gnuplot script ---
REM     Filename = "test_epslatex_stanalone.tex" 
REM     set terminal epslatex standalone newstyle dashlength 3.0 linewidth 2.0 rounded blacktext
REM     set terminal epslatex font "" 12
REM     set output Filename
REM     plot [0:1.0] sin(x)
REM     unset output
REM     system(sprintf("%s %s %s %s", "gnuplot2ps.bat", Filename, "pdflatex", "dbg"))             
REM     ## --- end gnuplot script ---

REM Custom variables:
REM MiKTeX Path
SET miktexpath=C:\Programme\MiKTeX 2.8\miktex\bin\
REM --- Settings for dvips: ---------------------------------------------------------------------------
REM # Notes: dvips settings 
REM ;  Option -Ppdf makes trouble, you have to check with the MiKTeX package manager if you have
REM ;  all necessary, T1 fonts, please check if you have the following packages:
REM ;    >>  cm-super, qxcm, cmpica, cmextra, ttcmex  <<
REM ;    and perhaps: >> psnfss, psnfssx, tex-ps <<
REM ;  the option -Ppdf tells dvipds to use the configfile config.pdf
REM ;  config.amz and config.cmz may be obsolet, the tip to load them was found in the english LaTeX-FAQ
REM ;  config.amz and config.cmz are part of the (obsolet) package "bluesky" 
REM ;  You can find infos, which METAFONT modes are known on your system with the command: initexmf --list-modes
REM ;  on my system I have: dpdfezzz   4000x4000   dvips -Ppdf (8000dpi)
REM ;  see also: http://www.grassbook.org/neteler/highres_pdf.html
REM ;  and: http://www.karakas-online.de/mySGML/embedding-computer-modern-fonts.html
REM ;  # -j0 -G0: tells dvips to embed the fonts 100%
REM ;  # -Pdownload35 or -u ps2pk.map: configuration of PostScript Type 1 fonts
REM ;  if you use the LaTeX-package "hyperref" and you see the error message: 
REM ;  "Note that an absolute path or a relative path with .. are denied in -R2 mode."
REM ;  ceck the options for the "hyperref" package, it should include "dvips" as an argument
REM ;  and no "dvipdfm" 
REM ;  \usepackage[a4,dvips, ...]{hyperref}
REM ;  and add the same option for the "graphicx"-Package:
REM ;  \usepackage[dvips]{graphicx}
SET pslevel=-I 1
SET dvipsopt=-R0 -j0 -N0 -Ppdf -Pamz -Pcmz -Pdownload35 -G0 %pslevel% -D 1200 -Z -mode dpdfezzz
REM --- Settings for eps2eps.bat: ---------------------------------------------------------------------
REM set resolution for non vector graphic content (I prefer the resolution of (16000x16000 = -r16000x16000)
REM SET resulution=-r8000x8000
SET resulution=-r16000x16000
REM if want to use it as input for a PDF/X-1a compatible LaTeX source, Comapatibility level3 is a good choice
REM see "pdfy.sty" (part of LaTeX-package pdfx) 
SET pdfvers=-dCompatibilityLevel#3
REM I found these options in the config file of dvipdfm package "dvipdfmx.cfg"
SET pdfopts=-dAutoFilterGrayImages#false -dGrayImageFilter#/FlateEncode -dAutoFilterColorImages#false -dColorImageFilter#/FlateEncode
SET eps2epsopt=%resulution% %pdfvers% %pdfopts%

REM check the file extention
IF NOT "%~x1"==".tex" (
  ECHO.
  ECHO. ----------------------------------------------------------------
  ECHO. Wrong File Extention, batch skript terminates now!
  ECHO. ----------------------------------------------------------------
  ECHO.
  ECHO.
  exit
)

REM fix variable definitions
SET f_tex=%1
REM strip file extention "tex"
SET f_=%f_tex:.tex=%
SET f_tex=%f_%.tex
SET f_dvi=%f_%.dvi
SET f_ps=%f_%.ps
SET f_eps=%f_%.eps
SET f_pdf=%f_%.pdf
SET f_fig=%f_%-inc.eps
REM C:\windows\system32\kill.exe AcroRd32
REM call "C:\Programme\MiKTeX 2.8\miktex\bin\pdfclose.exe" --file=%f_pdf%
REM texify LaTeX-File
if /i "%2"=="pdflatex" (
  ECHO.
  ECHO.--- PDF mode of pdflatex ---
  ECHO.
  call "%miktexpath%pdflatex.exe"  -interaction=nonstopmode "\pdfoutput=1" "\input" %f_tex%
  ECHO.
  ECHO.--- PDF mode of pdflatex done! ---
  IF "%3"==""  GOTO :EOF
  pause
)

if "%3"=="" (
  ECHO.
  ECHO.--- texify ---
  ECHO.
  REM call "%miktexpath%texify.exe" --quiet --clean %f_tex%
  call "%miktexpath%pdflatex.exe"  -interaction=nonstopmode "\pdfoutput=0" "\input" %f_tex%
  REM If option -Ppdf makes trouble, you have to check with the MiKTeX package manager if you have
  REM all necessary, T1 fonts, please check if you have the following packages:
  REM ;    >>  cm-super, qxcm, cmpica, cmextra, ttcmex  <<
  REM ;    and perhaps: >> psnfss, psnfssx, tex-ps <<
  REM C:\Programme\MiKTeX 2.8\miktex\bin\dvips.exe %f_dvi% -N0 -Pamz -Ppdf -G0 -o %f_ps%
  REM Remark: I found somewhere the advice to use the options "-Pamz -Pcmz", but I'm not sure, if you need it.) 
  ECHO.
  ECHO.--- dvips ---
  ECHO.
  call "%miktexpath%dvips.exe" %f_dvi% %dvipsopt% -o %f_ps%
) else (
  ECHO.
  ECHO.#   ***  Debug Option on  ***   #
  ECHO.
  @echo on
  REM call "%miktexpath%texify.exe" --verbose %f_tex%
  call "%miktexpath%pdflatex.exe" -recorder -interaction=nonstopmode "\pdfoutput=0 " "\input" %f_tex%
  ECHO.
  ECHO.--- dvips ---
  ECHO.
  call "%miktexpath%dvips.exe" %f_dvi% %dvipsopt%  -o %f_ps%
  @echo off
  ECHO.
  PAUSE
)

if /i "%2"=="eps" (
  ECHO.
  ECHO. --- epsoutput ---
  ECHO.
  ECHO.second arg0 %2
  REM we do not use the eps option of dvips.exe, because of the bad border determination
  REM hence, we have to call eps2eps.bat script, that is part of ghostscript
  call "%miktexpath%dvips.exe" %f_dvi% %dvipsopt% -o %f_ps%
  REM crop image via eps2eps
  ECHO.eps2eps "%eps2epsopt%" %f_ps% %f_eps%
  call eps2eps "%eps2epsopt%" %f_ps% %f_eps%
  ECHO --- eps2eps --- done! ---
  REM pause
  if exist %f_ps% del %f_ps% 
  GOTO :delfiles
) 

if /i "%2"=="pdf" (
  REM I tried to do the job with "pdflatex" in "pdf-mode" but failed at first, the pdf file was badly shaped
  REM to do the job "pdflatex" in "pdf-mode" load the "epstopdf" package after the "graphicx"-package
  ECHO.
  ECHO. --- pdfoutput ---
  ECHO.
  ECHO.second arg0 %2
  REM we do not use the eps option of dvips.exe, because of the bad crop quality
  REM hence, we have to call eps2eps.bat script, that is part of ghostscript
  call "%miktexpath%dvips.exe" %f_dvi% %dvipsopt% -o %f_ps%
  REM crop image via eps2eps
  ECHO.eps2eps "%eps2epsopt%" %f_ps% %f_eps%
  call eps2eps "%eps2epsopt%" %f_ps% %f_eps%
  ECHO --- eps2eps --- done! ---
  call ps2pdf -dEPSCrop %f_eps% %f_pdf%
  ECHO --- ps2pdf --- done! ---
  if exist %f_ps% del %f_ps% 
  if exist %f_eps% del %f_eps% 
  GOTO :delfiles
) 

  
:delfiles
  ECHO.
  ECHO. --- delete files ---
  ECHO.
  REM Delete auxiliary files
  if not "%3"=="" @echo off
  REM delete other files:
  if exist %f_%.aux del %f_%.aux
  if exist %f_%.dvi del %f_%.dvi
  if exist %f_tex% del %f_tex%
  if exist %f_fig% del %f_fig%
  if "%3"=="" (
    if exist %f_tex% del %f_tex%
    if exist %f_%.fls del %f_%.fls
    if exist %f_%.log del %f_%.log
  ) ELSE (
    PAUSE
  )
